﻿// Copyright 2021 Esri
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using System;
using System.Collections.Generic;
using System.Text;

using Esri.ArcGISRuntime.Geometry;
using Esri.ArcGISRuntime.Mapping;
using System.ComponentModel;
using System.Runtime.CompilerServices;

using Esri.ArcGISRuntime.Portal;
using System.Threading.Tasks;

namespace DisplayAWebScene
{

    class SceneViewModel : INotifyPropertyChanged
    {

        public SceneViewModel()
        {

            _ = SetupScene();

        }

        public event PropertyChangedEventHandler? PropertyChanged;
        protected void OnPropertyChanged([CallerMemberName] string propertyName = "")
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        private Scene? _scene;
        public Scene? Scene
        {
            get { return _scene; }
            set
            {
                _scene = value;
                OnPropertyChanged();
            }
        }

        private async Task SetupScene()
        {

            // Create a portal. If a URI is not specified, www.arcgis.com is used by default.
            ArcGISPortal portal = await ArcGISPortal.CreateAsync();

            // Get the portal item for a web scene using its unique item id.
            PortalItem sceneItem = await PortalItem.CreateAsync(portal, "579f97b2f3b94d4a8e48a5f140a6639b");

            // Create the scene from the item.
            Scene scene = new Scene(sceneItem);

            // To display the scene, set the SceneViewModel.Scene property, which is bound to the scene view.
            this.Scene = scene;

        }

    }

}


